@@ -51,7 +51,7 @@ RULE_OPS = {'and', 'or'}
 
 class SpecSecCustomRulesMain(object):
 
-    def __init__(self, target_obj, openapi_ver, linenum_mapping=None):
+    def __init__(self, target_obj, target_filename, openapi_ver, linenum_mapping=None):
         """
         Description
 
@@ -68,6 +68,7 @@ class SpecSecCustomRulesMain(object):
             Result desc
         """
         self.spec_main = SpecSecMain(target_obj=target_obj,
+                                     target_filename=target_filename,
                                      openapi_ver=openapi_ver)
         self.num_evaluations = 0
         self.linenum_mapping = linenum_mapping
